@@ -4,7 +4,6 @@ import os
 import sys
 import yaml
 import shutil
-import re
 import igraph
 from numba import jit, cuda, prange
 from functools import wraps
@@ -196,6 +195,12 @@ def normal_vector(vector):
         return vector / mag
 
 
+def empty_array(shape, dtype):
+    """ Create empty array based on data type.
+    """
+    return np.empty(shape, dtype=object) if dtype in (str, tuple, object) else np.zeros(shape, dtype=dtype)
+
+
 def record_time(function):
     """ This is a decorator used to time individual methods.
     """
